<?php

namespace Litecms\Practice\Policies;

use Litepie\User\Contracts\UserPolicy;
use Litecms\Practice\Models\Practice;

class PracticePolicy
{

    /**
     * Determine if the given user can view the practice.
     *
     * @param UserPolicy $user
     * @param Practice $practice
     *
     * @return bool
     */
    public function view(UserPolicy $user, Practice $practice)
    {
        if ($user->canDo('practice.practice.view') && $user->isAdmin()) {
            return true;
        }

        return $practice->user_id == user_id() && $practice->user_type == user_type();
    }

    /**
     * Determine if the given user can create a practice.
     *
     * @param UserPolicy $user
     * @param Practice $practice
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('practice.practice.create');
    }

    /**
     * Determine if the given user can update the given practice.
     *
     * @param UserPolicy $user
     * @param Practice $practice
     *
     * @return bool
     */
    public function update(UserPolicy $user, Practice $practice)
    {
        if ($user->canDo('practice.practice.edit') && $user->isAdmin()) {
            return true;
        }

        return $practice->user_id == user_id() && $practice->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given practice.
     *
     * @param UserPolicy $user
     * @param Practice $practice
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Practice $practice)
    {
        return $practice->user_id == user_id() && $practice->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given practice.
     *
     * @param UserPolicy $user
     * @param Practice $practice
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Practice $practice)
    {
        if ($user->canDo('practice.practice.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given practice.
     *
     * @param UserPolicy $user
     * @param Practice $practice
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Practice $practice)
    {
        if ($user->canDo('practice.practice.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
